package com.tutorialesprogramacionya.compose12

import android.content.Context
import android.os.Bundle
import androidx.activity.ComponentActivity
import androidx.activity.compose.setContent
import androidx.compose.foundation.Image
import androidx.compose.foundation.clickable
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.padding
import androidx.compose.foundation.layout.width
import androidx.compose.foundation.lazy.LazyColumn
import androidx.compose.foundation.lazy.itemsIndexed
import androidx.compose.material.Button
import androidx.compose.material.Divider
import androidx.compose.material.OutlinedTextField
import androidx.compose.material.Text
import androidx.compose.runtime.*
import androidx.compose.ui.Modifier
import androidx.compose.ui.graphics.Color
import androidx.compose.ui.platform.LocalContext
import androidx.compose.ui.res.painterResource
import androidx.compose.ui.unit.dp
import java.io.File

class MainActivity : ComponentActivity() {
    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)
        leerDatos()
        setContent {
            AdministrarContactos()
        }
    }

    fun leerDatos() {
        val file = File(filesDir, "contactos.txt")
        if (file.exists()) {
            val lista = file.readLines()
            var indice = 0
            while (indice < lista.size) {
                contactos.add(Contacto(lista.get(indice), lista.get(indice + 1)))
                indice += 2
            }
        }
    }
}

data class Contacto(val nombre: String, val mail: String)

val contactos = mutableStateListOf<Contacto>()


@Composable
fun AdministrarContactos() {
    val activity = LocalContext.current

    var nombre by remember { mutableStateOf("") }
    var mail by remember { mutableStateOf("") }
    Column() {
        OutlinedTextField(value = nombre,
            onValueChange = { nombre = it },
            label = { Text("Nombre de contacto") },
            modifier = Modifier
                .fillMaxWidth()
                .padding(5.dp)
        )
        OutlinedTextField(value = mail,
            onValueChange = { mail = it },
            label = { Text("mail") },
            modifier = Modifier
                .fillMaxWidth()
                .padding(5.dp)
        )
        Button(onClick = {
            val nuevoContacto = Contacto(nombre, mail)
            contactos.add(nuevoContacto)
            val path = activity.getFilesDir()
            val file = File(path, "contactos.txt")
            file.appendText("${nombre}\n${mail}\n")
            nombre = ""
            mail = ""
        }) {
            Text(text = "Agregar", modifier = Modifier.fillMaxWidth())
        }
        LazyColumn() {
            itemsIndexed(contactos) { indice, contacto ->
                MostrarContacto(indice, contacto)
            }
        }
    }
}

@Composable
fun MostrarContacto(indice: Int, contacto: Contacto) {
    val context = LocalContext.current
    Text(text = contacto.nombre)
    Text(text = contacto.mail)
    Image(painter = painterResource(id = android.R.drawable.ic_delete), contentDescription = "",
        modifier = Modifier.clickable {
            contactos.removeAt(indice)
            grabarCambios(context)
        })
    Divider(
        modifier = Modifier
            .fillMaxWidth()
            .width(4.dp), color = Color.Black
    )
}

fun grabarCambios(context: Context) {
    val file = File(context.filesDir, "contactos.txt")
    file.delete()
    for (contacto in contactos) {
        file.appendText("${contacto.nombre}\n${contacto.mail}\n")
    }
}